==> kadaster-gds2-1.4-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstgbresultaat/afgifte/v20130701/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbresultaat.afgifte.v20130701;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbresultaat.afgifte.v20130701 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _AfgifteGB_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstgbresultaat/afgifte/v20130701", "AfgifteGB");
    private final static QName _BestandenLijstGB_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstgbresultaat/afgifte/v20130701", "BestandenLijstGB");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbresultaat.afgifte.v20130701
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link AfgifteGBType }
     * 
     */
    public AfgifteGBType createAfgifteGBType() {
        return new AfgifteGBType();
    }

    /**
     * Create an instance of {@link BestandenLijstGBType }
     * 
     */
    public BestandenLijstGBType createBestandenLijstGBType() {
        return new BestandenLijstGBType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AfgifteGBType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstgbresultaat/afgifte/v20130701", name = "AfgifteGB")
    public JAXBElement<AfgifteGBType> createAfgifteGB(AfgifteGBType value) {
        return new JAXBElement<AfgifteGBType>(_AfgifteGB_QNAME, AfgifteGBType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BestandenLijstGBType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstgbresultaat/afgifte/v20130701", name = "BestandenLijstGB")
    public JAXBElement<BestandenLijstGBType> createBestandenLijstGB(BestandenLijstGBType value) {
        return new JAXBElement<BestandenLijstGBType>(_BestandenLijstGB_QNAME, BestandenLijstGBType.class, null, value);
    }

}

==> kadaster-gds2-2.5-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstgbresultaat/afgifte/v20130701/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbresultaat.afgifte.v20130701;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbresultaat.afgifte.v20130701 package. 
 * &lt;p&gt;An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _AfgifteGB_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstgbresultaat/afgifte/v20130701", "AfgifteGB");
    private final static QName _BestandenLijstGB_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstgbresultaat/afgifte/v20130701", "BestandenLijstGB");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbresultaat.afgifte.v20130701
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link AfgifteGBType }
     * 
     */
    public AfgifteGBType createAfgifteGBType() {
        return new AfgifteGBType();
    }

    /**
     * Create an instance of {@link BestandenLijstGBType }
     * 
     */
    public BestandenLijstGBType createBestandenLijstGBType() {
        return new BestandenLijstGBType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AfgifteGBType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link AfgifteGBType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstgbresultaat/afgifte/v20130701", name = "AfgifteGB")
    public JAXBElement<AfgifteGBType> createAfgifteGB(AfgifteGBType value) {
        return new JAXBElement<AfgifteGBType>(_AfgifteGB_QNAME, AfgifteGBType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BestandenLijstGBType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link BestandenLijstGBType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstgbresultaat/afgifte/v20130701", name = "BestandenLijstGB")
    public JAXBElement<BestandenLijstGBType> createBestandenLijstGB(BestandenLijstGBType value) {
        return new JAXBElement<BestandenLijstGBType>(_BestandenLijstGB_QNAME, BestandenLijstGBType.class, null, value);
    }

}
